@@ -9,10 +9,9 @@ require File.join(File.dirname(__FILE__), 'ping/udp')
 require File.join(File.dirname(__FILE__), 'ping/icmp')
 require File.join(File.dirname(__FILE__), 'ping/external')
 require File.join(File.dirname(__FILE__), 'ping/http')
-require File.join(File.dirname(__FILE__), 'ping/ldap')
 
 RbConfig = Config unless Object.const_defined?(:RbConfig)
 
-if RbConfig::CONFIG['host_os'] =~ /msdos|mswin|cygwin|mingw|win32|windows/i
+if File::ALT_SEPARATOR
   require File.join(File.dirname(__FILE__), 'ping/wmi')
 end
